package com.mysql.jdbc;

import java.io.ByteArrayOutputStream;
import java.io.UnsupportedEncodingException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.math.BigDecimal;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/StringUtils.class */
public class StringUtils {
    private static final int BYTE_RANGE = 256;
    private static byte[] allBytes = new byte[BYTE_RANGE];
    private static char[] byteToChars = new char[BYTE_RANGE];
    private static Method toPlainStringMethod;
    static final int WILD_COMPARE_MATCH_NO_WILD = 0;
    static final int WILD_COMPARE_MATCH_WITH_WILD = 1;
    static final int WILD_COMPARE_NO_MATCH = -1;
    static Class class$java$math$BigDecimal;

    static {
        Class cls;
        for (int i = -128; i <= 127; i++) {
            allBytes[i - (-128)] = (byte) i;
        }
        String allBytesString = new String(allBytes, 0, 255);
        int allBytesStringLen = allBytesString.length();
        for (int i2 = 0; i2 < 255 && i2 < allBytesStringLen; i2++) {
            byteToChars[i2] = allBytesString.charAt(i2);
        }
        try {
            if (class$java$math$BigDecimal == null) {
                cls = class$("java.math.BigDecimal");
                class$java$math$BigDecimal = cls;
            } else {
                cls = class$java$math$BigDecimal;
            }
            toPlainStringMethod = cls.getMethod("toPlainString", new Class[0]);
        } catch (NoSuchMethodException e) {
        }
    }

    static Class class$(String x0) {
        try {
            return Class.forName(x0);
        } catch (ClassNotFoundException x1) {
            throw new NoClassDefFoundError(x1.getMessage());
        }
    }

    public static String consistentToString(BigDecimal decimal) {
        if (decimal == null) {
            return null;
        }
        if (toPlainStringMethod != null) {
            try {
                return (String) toPlainStringMethod.invoke(decimal, null);
            } catch (IllegalAccessException e) {
            } catch (InvocationTargetException e2) {
            }
        }
        return decimal.toString();
    }

    public static final String dumpAsHex(byte[] byteBuffer, int length) {
        StringBuffer outputBuf = new StringBuffer(length * 4);
        int p = 0;
        int rows = length / 8;
        for (int i = 0; i < rows && p < length; i++) {
            int ptemp = p;
            for (int j = 0; j < 8; j++) {
                String hexVal = Integer.toHexString(byteBuffer[ptemp] & 255);
                if (hexVal.length() == 1) {
                    hexVal = new StringBuffer().append("0").append(hexVal).toString();
                }
                outputBuf.append(new StringBuffer().append(hexVal).append(" ").toString());
                ptemp++;
            }
            outputBuf.append("    ");
            for (int j2 = 0; j2 < 8; j2++) {
                int b = 255 & byteBuffer[p];
                if (b > 32 && b < 127) {
                    outputBuf.append(new StringBuffer().append((char) b).append(" ").toString());
                } else {
                    outputBuf.append(". ");
                }
                p++;
            }
            outputBuf.append("\n");
        }
        int n = 0;
        for (int i2 = p; i2 < length; i2++) {
            String hexVal2 = Integer.toHexString(byteBuffer[i2] & 255);
            if (hexVal2.length() == 1) {
                hexVal2 = new StringBuffer().append("0").append(hexVal2).toString();
            }
            outputBuf.append(new StringBuffer().append(hexVal2).append(" ").toString());
            n++;
        }
        for (int i3 = n; i3 < 8; i3++) {
            outputBuf.append("   ");
        }
        outputBuf.append("    ");
        for (int i4 = p; i4 < length; i4++) {
            int b2 = 255 & byteBuffer[i4];
            if (b2 > 32 && b2 < 127) {
                outputBuf.append(new StringBuffer().append((char) b2).append(" ").toString());
            } else {
                outputBuf.append(". ");
            }
        }
        outputBuf.append("\n");
        return outputBuf.toString();
    }

    private static boolean endsWith(byte[] dataFrom, String suffix) {
        for (int i = 1; i <= suffix.length(); i++) {
            int dfOffset = dataFrom.length - i;
            int suffixOffset = suffix.length() - i;
            if (dataFrom[dfOffset] != suffix.charAt(suffixOffset)) {
                return false;
            }
        }
        return true;
    }

    public static byte[] escapeEasternUnicodeByteStream(byte[] origBytes, String origString, int offset, int length) {
        if (origBytes == null || origBytes.length == 0) {
            return origBytes;
        }
        int bytesLen = origBytes.length;
        int bufIndex = 0;
        int strIndex = 0;
        ByteArrayOutputStream bytesOut = new ByteArrayOutputStream(bytesLen);
        while (true) {
            if (origString.charAt(strIndex) == '\\') {
                int i = bufIndex;
                bufIndex++;
                bytesOut.write(origBytes[i]);
            } else {
                int loByte = origBytes[bufIndex];
                if (loByte < 0) {
                    loByte += BYTE_RANGE;
                }
                bytesOut.write(loByte);
                if (loByte >= 128) {
                    if (bufIndex < bytesLen - 1) {
                        int hiByte = origBytes[bufIndex + 1];
                        if (hiByte < 0) {
                            hiByte += BYTE_RANGE;
                        }
                        bytesOut.write(hiByte);
                        bufIndex++;
                        if (hiByte == 92) {
                            bytesOut.write(hiByte);
                        }
                    }
                } else if (loByte == 92 && bufIndex < bytesLen - 1) {
                    int hiByte2 = origBytes[bufIndex + 1];
                    if (hiByte2 < 0) {
                        hiByte2 += BYTE_RANGE;
                    }
                    if (hiByte2 == 98) {
                        bytesOut.write(92);
                        bytesOut.write(98);
                        bufIndex++;
                    }
                }
                bufIndex++;
            }
            if (bufIndex < bytesLen) {
                strIndex++;
            } else {
                return bytesOut.toByteArray();
            }
        }
    }

    public static char firstNonWsCharUc(String searchIn) {
        return firstNonWsCharUc(searchIn, 0);
    }

    public static char firstNonWsCharUc(String searchIn, int startAt) {
        if (searchIn == null) {
            return (char) 0;
        }
        int length = searchIn.length();
        for (int i = startAt; i < length; i++) {
            char c = searchIn.charAt(i);
            if (!Character.isWhitespace(c)) {
                return Character.toUpperCase(c);
            }
        }
        return (char) 0;
    }

    public static final String fixDecimalExponent(String dString) {
        char maybeMinusChar;
        int ePos = dString.indexOf("E");
        if (ePos == -1) {
            ePos = dString.indexOf("e");
        }
        if (ePos != -1 && dString.length() > ePos + 1 && (maybeMinusChar = dString.charAt(ePos + 1)) != '-' && maybeMinusChar != '+') {
            StringBuffer buf = new StringBuffer(dString.length() + 1);
            buf.append(dString.substring(0, ePos + 1));
            buf.append('+');
            buf.append(dString.substring(ePos + 1, dString.length()));
            dString = buf.toString();
        }
        return dString;
    }

    public static final byte[] getBytes(char[] c, SingleByteCharsetConverter converter, String encoding, String serverEncoding, boolean parserKnowsUnicode) throws SQLException {
        byte[] b;
        try {
            if (converter != null) {
                b = converter.toBytes(c);
            } else if (encoding == null) {
                b = new String(c).getBytes();
            } else {
                String s = new String(c);
                b = s.getBytes(encoding);
                if (!parserKnowsUnicode && ((encoding.equalsIgnoreCase("SJIS") || encoding.equalsIgnoreCase("BIG5") || encoding.equalsIgnoreCase("GBK")) && !encoding.equalsIgnoreCase(serverEncoding))) {
                    b = escapeEasternUnicodeByteStream(b, s, 0, s.length());
                }
            }
            return b;
        } catch (UnsupportedEncodingException e) {
            throw SQLError.createSQLException(new StringBuffer().append(Messages.getString("StringUtils.5")).append(encoding).append(Messages.getString("StringUtils.6")).toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    public static final byte[] getBytes(char[] c, SingleByteCharsetConverter converter, String encoding, String serverEncoding, int offset, int length, boolean parserKnowsUnicode) throws SQLException {
        byte[] b;
        try {
            if (converter != null) {
                b = converter.toBytes(c, offset, length);
            } else if (encoding == null) {
                byte[] temp = new String(c, offset, length).getBytes();
                int length2 = temp.length;
                b = new byte[length2];
                System.arraycopy(temp, 0, b, 0, length2);
            } else {
                String s = new String(c, offset, length);
                byte[] temp2 = s.getBytes(encoding);
                int length3 = temp2.length;
                b = new byte[length3];
                System.arraycopy(temp2, 0, b, 0, length3);
                if (!parserKnowsUnicode && ((encoding.equalsIgnoreCase("SJIS") || encoding.equalsIgnoreCase("BIG5") || encoding.equalsIgnoreCase("GBK")) && !encoding.equalsIgnoreCase(serverEncoding))) {
                    b = escapeEasternUnicodeByteStream(b, s, offset, length3);
                }
            }
            return b;
        } catch (UnsupportedEncodingException e) {
            throw SQLError.createSQLException(new StringBuffer().append(Messages.getString("StringUtils.10")).append(encoding).append(Messages.getString("StringUtils.11")).toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    public static final byte[] getBytes(char[] c, String encoding, String serverEncoding, boolean parserKnowsUnicode, ConnectionImpl conn) throws SQLException {
        SingleByteCharsetConverter converter;
        try {
            if (conn != null) {
                converter = conn.getCharsetConverter(encoding);
            } else {
                converter = SingleByteCharsetConverter.getInstance(encoding, null);
            }
            return getBytes(c, converter, encoding, serverEncoding, parserKnowsUnicode);
        } catch (UnsupportedEncodingException e) {
            throw SQLError.createSQLException(new StringBuffer().append(Messages.getString("StringUtils.0")).append(encoding).append(Messages.getString("StringUtils.1")).toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    public static final byte[] getBytes(String s, SingleByteCharsetConverter converter, String encoding, String serverEncoding, boolean parserKnowsUnicode) throws SQLException {
        byte[] b;
        try {
            if (converter != null) {
                b = converter.toBytes(s);
            } else if (encoding == null) {
                b = s.getBytes();
            } else {
                b = s.getBytes(encoding);
                if (!parserKnowsUnicode && ((encoding.equalsIgnoreCase("SJIS") || encoding.equalsIgnoreCase("BIG5") || encoding.equalsIgnoreCase("GBK")) && !encoding.equalsIgnoreCase(serverEncoding))) {
                    b = escapeEasternUnicodeByteStream(b, s, 0, s.length());
                }
            }
            return b;
        } catch (UnsupportedEncodingException e) {
            throw SQLError.createSQLException(new StringBuffer().append(Messages.getString("StringUtils.5")).append(encoding).append(Messages.getString("StringUtils.6")).toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    public static final byte[] getBytesWrapped(String s, char beginWrap, char endWrap, SingleByteCharsetConverter converter, String encoding, String serverEncoding, boolean parserKnowsUnicode) throws SQLException {
        byte[] b;
        try {
            if (converter != null) {
                b = converter.toBytesWrapped(s, beginWrap, endWrap);
            } else if (encoding == null) {
                StringBuffer buf = new StringBuffer(s.length() + 2);
                buf.append(beginWrap);
                buf.append(s);
                buf.append(endWrap);
                b = buf.toString().getBytes();
            } else {
                StringBuffer buf2 = new StringBuffer(s.length() + 2);
                buf2.append(beginWrap);
                buf2.append(s);
                buf2.append(endWrap);
                b = buf2.toString().getBytes(encoding);
                if (!parserKnowsUnicode && ((encoding.equalsIgnoreCase("SJIS") || encoding.equalsIgnoreCase("BIG5") || encoding.equalsIgnoreCase("GBK")) && !encoding.equalsIgnoreCase(serverEncoding))) {
                    b = escapeEasternUnicodeByteStream(b, s, 0, s.length());
                }
            }
            return b;
        } catch (UnsupportedEncodingException e) {
            throw SQLError.createSQLException(new StringBuffer().append(Messages.getString("StringUtils.5")).append(encoding).append(Messages.getString("StringUtils.6")).toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    public static final byte[] getBytes(String s, SingleByteCharsetConverter converter, String encoding, String serverEncoding, int offset, int length, boolean parserKnowsUnicode) throws SQLException {
        byte[] b;
        try {
            if (converter != null) {
                b = converter.toBytes(s, offset, length);
            } else if (encoding == null) {
                byte[] temp = s.substring(offset, offset + length).getBytes();
                int length2 = temp.length;
                b = new byte[length2];
                System.arraycopy(temp, 0, b, 0, length2);
            } else {
                byte[] temp2 = s.substring(offset, offset + length).getBytes(encoding);
                int length3 = temp2.length;
                b = new byte[length3];
                System.arraycopy(temp2, 0, b, 0, length3);
                if (!parserKnowsUnicode && ((encoding.equalsIgnoreCase("SJIS") || encoding.equalsIgnoreCase("BIG5") || encoding.equalsIgnoreCase("GBK")) && !encoding.equalsIgnoreCase(serverEncoding))) {
                    b = escapeEasternUnicodeByteStream(b, s, offset, length3);
                }
            }
            return b;
        } catch (UnsupportedEncodingException e) {
            throw SQLError.createSQLException(new StringBuffer().append(Messages.getString("StringUtils.10")).append(encoding).append(Messages.getString("StringUtils.11")).toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    public static final byte[] getBytes(String s, String encoding, String serverEncoding, boolean parserKnowsUnicode, ConnectionImpl conn) throws SQLException {
        SingleByteCharsetConverter converter;
        try {
            if (conn != null) {
                converter = conn.getCharsetConverter(encoding);
            } else {
                converter = SingleByteCharsetConverter.getInstance(encoding, null);
            }
            return getBytes(s, converter, encoding, serverEncoding, parserKnowsUnicode);
        } catch (UnsupportedEncodingException e) {
            throw SQLError.createSQLException(new StringBuffer().append(Messages.getString("StringUtils.0")).append(encoding).append(Messages.getString("StringUtils.1")).toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    public static int getInt(byte[] buf, int offset, int endPos) throws NumberFormatException {
        char c;
        int s = offset;
        while (Character.isWhitespace((char) buf[s]) && s < endPos) {
            s++;
        }
        if (s == endPos) {
            throw new NumberFormatException(new String(buf));
        }
        boolean negative = false;
        if (((char) buf[s]) == '-') {
            negative = true;
            s++;
        } else if (((char) buf[s]) == '+') {
            s++;
        }
        int save = s;
        int cutoff = Integer.MAX_VALUE / 10;
        int cutlim = Integer.MAX_VALUE % 10;
        if (negative) {
            cutlim++;
        }
        boolean overflow = false;
        int i = 0;
        while (s < endPos) {
            char c2 = (char) buf[s];
            if (Character.isDigit(c2)) {
                c = (char) (c2 - '0');
            } else {
                if (!Character.isLetter(c2)) {
                    break;
                }
                c = (char) ((Character.toUpperCase(c2) - 'A') + 10);
            }
            if (c >= '\n') {
                break;
            }
            if (i > cutoff || (i == cutoff && c > cutlim)) {
                overflow = true;
            } else {
                i = (i * 10) + c;
            }
            s++;
        }
        if (s == save) {
            throw new NumberFormatException(new String(buf));
        }
        if (overflow) {
            throw new NumberFormatException(new String(buf));
        }
        return negative ? -i : i;
    }

    public static int getInt(byte[] buf) throws NumberFormatException {
        return getInt(buf, 0, buf.length);
    }

    public static long getLong(byte[] buf) throws NumberFormatException {
        return getLong(buf, 0, buf.length);
    }

    public static long getLong(byte[] buf, int offset, int endpos) throws NumberFormatException {
        char c;
        int s = offset;
        while (Character.isWhitespace((char) buf[s]) && s < endpos) {
            s++;
        }
        if (s == endpos) {
            throw new NumberFormatException(new String(buf));
        }
        boolean negative = false;
        if (((char) buf[s]) == '-') {
            negative = true;
            s++;
        } else if (((char) buf[s]) == '+') {
            s++;
        }
        int save = s;
        long cutoff = Long.MAX_VALUE / 10;
        long cutlim = (int) (Long.MAX_VALUE % 10);
        if (negative) {
            cutlim++;
        }
        boolean overflow = false;
        long i = 0;
        while (s < endpos) {
            char c2 = (char) buf[s];
            if (Character.isDigit(c2)) {
                c = (char) (c2 - '0');
            } else {
                if (!Character.isLetter(c2)) {
                    break;
                }
                c = (char) ((Character.toUpperCase(c2) - 'A') + 10);
            }
            if (c >= '\n') {
                break;
            }
            if (i > cutoff || (i == cutoff && c > cutlim)) {
                overflow = true;
            } else {
                i = (i * 10) + c;
            }
            s++;
        }
        if (s == save) {
            throw new NumberFormatException(new String(buf));
        }
        if (overflow) {
            throw new NumberFormatException(new String(buf));
        }
        return negative ? -i : i;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v45, types: [char] */
    /* JADX WARN: Type inference failed for: r0v59, types: [char] */
    public static short getShort(byte[] buf) throws NumberFormatException {
        short upperCase;
        int s = 0;
        while (Character.isWhitespace((char) buf[s]) && s < buf.length) {
            s++;
        }
        if (s == buf.length) {
            throw new NumberFormatException(new String(buf));
        }
        boolean negative = false;
        if (((char) buf[s]) == '-') {
            negative = true;
            s++;
        } else if (((char) buf[s]) == '+') {
            s++;
        }
        int save = s;
        short cutoff = (short) (32767 / 10);
        short cutlim = (short) (32767 % 10);
        if (negative) {
            cutlim = (short) (cutlim + 1);
        }
        boolean overflow = false;
        short i = 0;
        while (s < buf.length) {
            char c = (char) buf[s];
            if (Character.isDigit(c)) {
                upperCase = (char) (c - '0');
            } else {
                if (!Character.isLetter(c)) {
                    break;
                }
                upperCase = (char) ((Character.toUpperCase(c) - 'A') + 10);
            }
            if (upperCase >= 10) {
                break;
            }
            if (i > cutoff || (i == cutoff && upperCase > cutlim)) {
                overflow = true;
            } else {
                i = (short) (((short) (i * 10)) + upperCase);
            }
            s++;
        }
        if (s == save) {
            throw new NumberFormatException(new String(buf));
        }
        if (overflow) {
            throw new NumberFormatException(new String(buf));
        }
        return negative ? (short) (-i) : i;
    }

    public static final int indexOfIgnoreCase(int startingPosition, String searchIn, String searchFor) {
        if (searchIn == null || searchFor == null || startingPosition > searchIn.length()) {
            return -1;
        }
        int patternLength = searchFor.length();
        int stringLength = searchIn.length();
        int stopSearchingAt = stringLength - patternLength;
        int i = startingPosition;
        if (patternLength == 0) {
            return -1;
        }
        char firstCharOfPatternUc = Character.toUpperCase(searchFor.charAt(0));
        char firstCharOfPatternLc = Character.toLowerCase(searchFor.charAt(0));
        while (true) {
            if (i < stopSearchingAt && Character.toUpperCase(searchIn.charAt(i)) != firstCharOfPatternUc && Character.toLowerCase(searchIn.charAt(i)) != firstCharOfPatternLc) {
                i++;
            } else {
                if (i > stopSearchingAt) {
                    return -1;
                }
                int j = i + 1;
                int end = (j + patternLength) - 1;
                int k = 1;
                while (j < end) {
                    int searchInPos = j;
                    j++;
                    int searchForPos = k;
                    k++;
                    if (Character.toUpperCase(searchIn.charAt(searchInPos)) != Character.toUpperCase(searchFor.charAt(searchForPos))) {
                        i++;
                    } else if (Character.toLowerCase(searchIn.charAt(searchInPos)) != Character.toLowerCase(searchFor.charAt(searchForPos))) {
                        i++;
                    }
                }
                return i;
            }
        }
    }

    public static final int indexOfIgnoreCase(String searchIn, String searchFor) {
        return indexOfIgnoreCase(0, searchIn, searchFor);
    }

    public static int indexOfIgnoreCaseRespectMarker(int startAt, String src, String target, String marker, String markerCloses, boolean allowBackslashEscapes) {
        char contextMarker = 0;
        boolean escaped = false;
        int markerTypeFound = 0;
        int srcLength = src.length();
        for (int i = startAt; i < srcLength; i++) {
            char c = src.charAt(i);
            if (allowBackslashEscapes && c == '\\') {
                escaped = !escaped;
            } else if (c == markerCloses.charAt(markerTypeFound) && !escaped) {
                contextMarker = 0;
            } else {
                int ind = marker.indexOf(c);
                if (ind != -1 && !escaped && contextMarker == 0) {
                    markerTypeFound = ind;
                    contextMarker = c;
                } else if (c == target.charAt(0) && !escaped && contextMarker == 0 && indexOfIgnoreCase(i, src, target) != -1) {
                    return i;
                }
            }
        }
        return -1;
    }

    public static int indexOfIgnoreCaseRespectQuotes(int startAt, String src, String target, char quoteChar, boolean allowBackslashEscapes) {
        char contextMarker = 0;
        boolean escaped = false;
        int srcLength = src.length();
        for (int i = startAt; i < srcLength; i++) {
            char c = src.charAt(i);
            if (allowBackslashEscapes && c == '\\') {
                escaped = !escaped;
            } else if (c == contextMarker && !escaped) {
                contextMarker = 0;
            } else if (c == quoteChar && !escaped && contextMarker == 0) {
                contextMarker = c;
            } else if ((Character.toUpperCase(c) == Character.toUpperCase(target.charAt(0)) || Character.toLowerCase(c) == Character.toLowerCase(target.charAt(0))) && !escaped && contextMarker == 0 && startsWithIgnoreCase(src, i, target)) {
                return i;
            }
        }
        return -1;
    }

    public static final List split(String stringToSplit, String delimitter, boolean trim) {
        if (stringToSplit == null) {
            return new ArrayList();
        }
        if (delimitter == null) {
            throw new IllegalArgumentException();
        }
        StringTokenizer tokenizer = new StringTokenizer(stringToSplit, delimitter, false);
        List splitTokens = new ArrayList(tokenizer.countTokens());
        while (tokenizer.hasMoreTokens()) {
            String token = tokenizer.nextToken();
            if (trim) {
                token = token.trim();
            }
            splitTokens.add(token);
        }
        return splitTokens;
    }

    public static final List split(String stringToSplit, String delimiter, String markers, String markerCloses, boolean trim) {
        if (stringToSplit == null) {
            return new ArrayList();
        }
        if (delimiter == null) {
            throw new IllegalArgumentException();
        }
        int currentPos = 0;
        List splitTokens = new ArrayList();
        while (true) {
            int delimPos = indexOfIgnoreCaseRespectMarker(currentPos, stringToSplit, delimiter, markers, markerCloses, false);
            if (delimPos == -1) {
                break;
            }
            String token = stringToSplit.substring(currentPos, delimPos);
            if (trim) {
                token = token.trim();
            }
            splitTokens.add(token);
            currentPos = delimPos + 1;
        }
        if (currentPos < stringToSplit.length()) {
            String token2 = stringToSplit.substring(currentPos);
            if (trim) {
                token2 = token2.trim();
            }
            splitTokens.add(token2);
        }
        return splitTokens;
    }

    private static boolean startsWith(byte[] dataFrom, String chars) {
        for (int i = 0; i < chars.length(); i++) {
            if (dataFrom[i] != chars.charAt(i)) {
                return false;
            }
        }
        return true;
    }

    public static boolean startsWithIgnoreCase(String searchIn, int startAt, String searchFor) {
        return searchIn.regionMatches(true, startAt, searchFor, 0, searchFor.length());
    }

    public static boolean startsWithIgnoreCase(String searchIn, String searchFor) {
        return startsWithIgnoreCase(searchIn, 0, searchFor);
    }

    public static boolean startsWithIgnoreCaseAndNonAlphaNumeric(String searchIn, String searchFor) {
        if (searchIn == null) {
            return searchFor == null;
        }
        int inLength = searchIn.length();
        int beginPos = 0;
        while (beginPos < inLength) {
            char c = searchIn.charAt(beginPos);
            if (Character.isLetterOrDigit(c)) {
                break;
            }
            beginPos++;
        }
        return startsWithIgnoreCase(searchIn, beginPos, searchFor);
    }

    public static boolean startsWithIgnoreCaseAndWs(String searchIn, String searchFor) {
        return startsWithIgnoreCaseAndWs(searchIn, searchFor, 0);
    }

    public static boolean startsWithIgnoreCaseAndWs(String searchIn, String searchFor, int beginPos) {
        if (searchIn == null) {
            return searchFor == null;
        }
        int inLength = searchIn.length();
        while (beginPos < inLength && Character.isWhitespace(searchIn.charAt(beginPos))) {
            beginPos++;
        }
        return startsWithIgnoreCase(searchIn, beginPos, searchFor);
    }

    public static byte[] stripEnclosure(byte[] source, String prefix, String suffix) {
        if (source.length >= prefix.length() + suffix.length() && startsWith(source, prefix) && endsWith(source, suffix)) {
            int totalToStrip = prefix.length() + suffix.length();
            int enclosedLength = source.length - totalToStrip;
            byte[] enclosed = new byte[enclosedLength];
            int startPos = prefix.length();
            int numToCopy = enclosed.length;
            System.arraycopy(source, startPos, enclosed, 0, numToCopy);
            return enclosed;
        }
        return source;
    }

    public static final String toAsciiString(byte[] buffer) {
        return toAsciiString(buffer, 0, buffer.length);
    }

    public static final String toAsciiString(byte[] buffer, int startPos, int length) {
        char[] charArray = new char[length];
        int readpoint = startPos;
        for (int i = 0; i < length; i++) {
            charArray[i] = (char) buffer[readpoint];
            readpoint++;
        }
        return new String(charArray);
    }

    /* JADX WARN: Code restructure failed: missing block: B:101:0x0199, code lost:
    
        if (r5.charAt(0) != '%') goto L133;
     */
    /* JADX WARN: Code restructure failed: missing block: B:103:?, code lost:
    
        return -1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:107:0x019c, code lost:
    
        return -1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:110:0x018b, code lost:
    
        return r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:112:0x017b, code lost:
    
        return -1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:114:0x016b, code lost:
    
        r12 = r12 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:40:0x00b0, code lost:
    
        if (r5.charAt(r10) == '_') goto L41;
     */
    /* JADX WARN: Code restructure failed: missing block: B:42:0x00b7, code lost:
    
        if (r12 != r0) goto L45;
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x00bc, code lost:
    
        r12 = r12 + 1;
        r10 = r10 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:44:0x00c6, code lost:
    
        if (r10 >= r0) goto L118;
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x00d1, code lost:
    
        if (r5.charAt(r10) == '_') goto L119;
     */
    /* JADX WARN: Code restructure failed: missing block: B:49:0x00d8, code lost:
    
        if (r10 != r0) goto L52;
     */
    /* JADX WARN: Code restructure failed: missing block: B:59:0x00bb, code lost:
    
        return r6;
     */
    /* JADX WARN: Code restructure failed: missing block: B:61:0x00e5, code lost:
    
        if (r5.charAt(r10) != '%') goto L114;
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x00eb, code lost:
    
        r10 = r10 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:64:0x00ef, code lost:
    
        if (r10 == r0) goto L122;
     */
    /* JADX WARN: Code restructure failed: missing block: B:66:0x00f9, code lost:
    
        if (r5.charAt(r10) != '%') goto L60;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x0107, code lost:
    
        if (r5.charAt(r10) != '_') goto L120;
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x010e, code lost:
    
        if (r12 != r0) goto L66;
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x0113, code lost:
    
        r12 = r12 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:75:0x0111, code lost:
    
        return -1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:78:0x0120, code lost:
    
        if (r10 != r0) goto L72;
     */
    /* JADX WARN: Code restructure failed: missing block: B:79:0x0123, code lost:
    
        return 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:81:0x0129, code lost:
    
        if (r12 != r0) goto L76;
     */
    /* JADX WARN: Code restructure failed: missing block: B:82:0x012c, code lost:
    
        return -1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:83:0x012e, code lost:
    
        r0 = r5.charAt(r10);
        r15 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:84:0x0139, code lost:
    
        if (r0 != '\\') goto L81;
     */
    /* JADX WARN: Code restructure failed: missing block: B:86:0x0142, code lost:
    
        if ((r10 + 1) == r0) goto L81;
     */
    /* JADX WARN: Code restructure failed: missing block: B:87:0x0145, code lost:
    
        r10 = r10 + 1;
        r15 = r5.charAt(r10);
     */
    /* JADX WARN: Code restructure failed: missing block: B:88:0x0150, code lost:
    
        r10 = r10 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:90:0x0157, code lost:
    
        if (r12 == r0) goto L125;
     */
    /* JADX WARN: Code restructure failed: missing block: B:92:0x0168, code lost:
    
        if (java.lang.Character.toUpperCase(r4.charAt(r12)) == java.lang.Character.toUpperCase(r15)) goto L126;
     */
    /* JADX WARN: Code restructure failed: missing block: B:94:0x0171, code lost:
    
        r0 = r12;
        r12 = r12 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:95:0x0178, code lost:
    
        if (r0 != r0) goto L91;
     */
    /* JADX WARN: Code restructure failed: missing block: B:96:0x017d, code lost:
    
        r0 = wildCompare(r4, r5);
     */
    /* JADX WARN: Code restructure failed: missing block: B:97:0x0186, code lost:
    
        if (r0 > 0) goto L95;
     */
    /* JADX WARN: Code restructure failed: missing block: B:99:0x0190, code lost:
    
        if (r12 == r0) goto L129;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static int wildCompare(java.lang.String r4, java.lang.String r5) {
        /*
            Method dump skipped, instructions count: 430
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.StringUtils.wildCompare(java.lang.String, java.lang.String):int");
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static byte[] s2b(String s, ConnectionImpl conn) throws SQLException {
        if (s == null) {
            return null;
        }
        if (conn != null && conn.getUseUnicode()) {
            try {
                String encoding = conn.getEncoding();
                if (encoding == null) {
                    return s.getBytes();
                }
                SingleByteCharsetConverter converter = conn.getCharsetConverter(encoding);
                if (converter != null) {
                    return converter.toBytes(s);
                }
                return s.getBytes(encoding);
            } catch (UnsupportedEncodingException e) {
                return s.getBytes();
            }
        }
        return s.getBytes();
    }

    public static int lastIndexOf(byte[] s, char c) {
        if (s == null) {
            return -1;
        }
        for (int i = s.length - 1; i >= 0; i--) {
            if (s[i] == c) {
                return i;
            }
        }
        return -1;
    }

    public static int indexOf(byte[] s, char c) {
        if (s == null) {
            return -1;
        }
        int length = s.length;
        for (int i = 0; i < length; i++) {
            if (s[i] == c) {
                return i;
            }
        }
        return -1;
    }

    public static boolean isNullOrEmpty(String toTest) {
        return toTest == null || toTest.length() == 0;
    }

    /* JADX WARN: Removed duplicated region for block: B:42:0x01a5 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:46:0x002c A[SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static java.lang.String stripComments(java.lang.String r4, java.lang.String r5, java.lang.String r6, boolean r7, boolean r8, boolean r9, boolean r10) {
        /*
            Method dump skipped, instructions count: 444
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.StringUtils.stripComments(java.lang.String, java.lang.String, java.lang.String, boolean, boolean, boolean, boolean):java.lang.String");
    }

    public static final boolean isEmptyOrWhitespaceOnly(String str) {
        if (str == null || str.length() == 0) {
            return true;
        }
        int length = str.length();
        for (int i = 0; i < length; i++) {
            if (!Character.isWhitespace(str.charAt(i))) {
                return false;
            }
        }
        return true;
    }
}
